@@ -1,11 +1,14 @@
-"""Classes implementing different methods for running monasca-agent on startup as well as starting the process immediately
+"""Classes implementing different methods for running monasca-agent on startup as well as starting the process immediately.
+
 """
 import psutil
 
 
 class Service(object):
 
-    """Abstract base class implementing the interface for various service types."""
+    """Abstract base class implementing the interface for various service types.
+
+    """
 
     def __init__(self, config_dir, log_dir, name='monasca-agent'):
         self.config_dir = config_dir
@@ -14,29 +17,34 @@ class Service(object):
 
     def enable(self):
         """Sets monasca-agent to start on boot.
+
             Generally this requires running as super user
         """
         raise NotImplementedError
 
     def start(self, restart=True):
-        """Starts monasca-agent
+        """Starts monasca-agent.
+
             If the agent is running and restart is True, restart
         """
         raise NotImplementedError
 
     def stop(self):
-        """Stops monasca-agent
+        """Stops monasca-agent.
+
         """
         raise NotImplementedError
 
     def is_enabled(self):
-        """Returns True if monasca-agent is setup to start on boot, false otherwise
+        """Returns True if monasca-agent is setup to start on boot, false otherwise.
+
         """
         raise NotImplementedError
 
     @staticmethod
     def is_running():
-        """Returns True if monasca-agent is running, false otherwise
+        """Returns True if monasca-agent is running, false otherwise.
+
         """
         # Looking for the supervisor process not the individual components
         for process in psutil.process_iter():
